@@ -3,27 +3,23 @@ pub struct Config {
     pub buffering: usize,
     pub smoothing_size: usize,
     pub smoothing_amount: usize,
-    pub resolution: usize,
+    pub fft_resolution: usize,
     pub refresh_rate: usize,
-    pub frequency_scale_range: [usize; 2],
-    pub frequency_scale_amount: usize,
-    pub density_reduction: usize,
+    pub resolution: f32,
     pub max_frequency: usize,
     pub volume: f32,
 }
 impl Default for Config {
     fn default() -> Self {
         Config { 
-            buffering: 5,
-            smoothing_size: 10,
+            buffering: 6,
+            smoothing_size: 6,
             smoothing_amount: 5,
-            resolution: 3000,
+            fft_resolution: 2048,
             refresh_rate: 60,
-            frequency_scale_range: [50, 1000],
-            frequency_scale_amount: 1,
-            density_reduction: 5,
+            resolution: 1.0,
             max_frequency: 20_000,
-            volume: 1.0,
+            volume: 100.0,
         }
     }
 }
\ No newline at end of file
